@@ -34,18 +34,19 @@ GCONFPATH = "/apps/Maemo/tomch.com/%s" % APP_NAME
 #gtk.gdk.threads_init()
 
 class RecallerHomePlugin(hildondesktop.HomePluginItem):
-  #List of default values
-  defaultSOURCE = "Phone"
-  defaultFOLDER = "/home/user/MyDocs"
-  defaultFORMAT = "aac"
-  defaultAUTOREC = False
-  defaultBANNERS = True
-  
+
   def __init__(self):
     hildondesktop.HomePluginItem.__init__(self)
     self.set_settings(True)
     self.connect("show-settings", self.show_options)
 
+    #List of default values
+    self.defaultSOURCE = "Phone"
+    self.defaultFOLDER = "/home/user/MyDocs"
+    self.defaultFORMAT = "aac"
+    self.defaultAUTOREC = False
+    self.defaultBANNERS = True
+
     self.SHOWBANNER = True
     
     self.isStopped = True 
@@ -57,13 +58,14 @@ class RecallerHomePlugin(hildondesktop.HomePluginItem):
     conf_client = gconf.client_get_default()
     conf_client.add_dir(GCONFPATH, gconf.CLIENT_PRELOAD_NONE)
            
-    if False:  #Set to True if ever settings should be corrupt
+    if False:  #Set to True if ever settings should be corrupt during development. Will reset gconf values to initial settings
       conf_client.set_string(GCONFPATH+"/audiosource", self.defaultSOURCE)
       conf_client.set_string(GCONFPATH+"/folder", self.defaultFOLDER)
       conf_client.set_string(GCONFPATH+"/format", self.defaultFORMAT)
       conf_client.set_bool(GCONFPATH+"/autorec", self.defaultAUTOREC)
       conf_client.set_bool(GCONFPATH+"/reminders", self.defaultBANNERS)
-           
+    #Or remove the settings through the command line (good for QA :-)
+    #gconftool-2 --unset /apps/Maemo/tomch.com/recaller
     self.source=conf_client.get_string(GCONFPATH+"/audiosource")
     self.folder=conf_client.get_string(GCONFPATH+"/folder")
     self.fileformat=conf_client.get_string(GCONFPATH+"/format")
@@ -71,15 +73,15 @@ class RecallerHomePlugin(hildondesktop.HomePluginItem):
     self.reminders=conf_client.get_bool(GCONFPATH+"/reminders")
     print self.source,self.folder,self.fileformat,self.autorec,self.reminders
     if self.source == None:
-      self.source=defaultSOURCE
+      self.source=self.defaultSOURCE
     if self.folder == None:
-      self.folder=defaultFOLDER
+      self.folder=self.defaultFOLDER
     if self.fileformat == None:
-      self.fileformat = defaultFORMAT
+      self.fileformat = self.defaultFORMAT
     if self.autorec == None:
-      self.autorec = defaultAUTOREC
+      self.autorec = self.defaultAUTOREC
     if self.reminders == None:
-      self.reminders = defaultBANNERS
+      self.reminders = self.defaultBANNERS
       
     self.isStopped = True 
     self.transparency = 0.0 
